/*
 *  plugin-dir.h - Directory management for plugin configuration tool
 *
 *  by Martin Stransky <stransky@redhat.com>
 *
 *  This utility is based on:
 *
 *  npw-config.c - nspluginwrapper configuration tool 
 *  nspluginwrapper (C) 2005-2007 Gwenole Beauchesne
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <sys/types.h>
#include <unistd.h>
#include <string.h>
#include <pwd.h>
#include <limits.h>

#include "plugin-dir.h"
#include "plugin-path.h"

int get_bits(const char *p_arch)
{
  if(!strcmp(p_arch, "i386") || !strcmp(p_arch, "ppc")) {
    return(32);
  }
  else if(!strcmp(p_arch, "x86_64") || !strcmp(p_arch, "ppc64")) {
    return(64);
  } 
  else {    
    return(0);
  }  
}

WRAP_NAME * get_plugin_dir_32(void)
{  
  static WRAP_NAME system_dir_32 = { NPW_PLUGIN_DIR_32, NPW_PLUGIN_DIR_32_WRAPPED };
  return(&system_dir_32);
}

WRAP_NAME * get_plugin_dir_64(void)
{  
  static WRAP_NAME system_dir_64 = { NPW_PLUGIN_DIR_64, NPW_PLUGIN_DIR_64_WRAPPED };
  return(&system_dir_64);
}

WRAP_NAME * get_plugin_dir_bits(int bits)
{  
  if(bits == 32) {
    return(get_plugin_dir_32());
  }
  else if(bits == 64) {
    return(get_plugin_dir_64());
  } 
  else {
    assert(0);
    return(NULL);
  }
}

WRAP_NAME * get_plugin_dir(const char *p_arch)
{
  return(get_plugin_dir_bits(get_bits(p_arch)));
}

WRAP_NAME * get_plugin_bits(int bits, const char *p_plugin)
{
  static WRAP_NAME plugin;

  WRAP_NAME *p_dir = get_plugin_dir_bits(bits);  
  
  snprintf(plugin.name,MAX_NAME,"%s/%s",p_dir->name,p_plugin);
  snprintf(plugin.name_wrapped,MAX_NAME,"%s/%s",p_dir->name_wrapped,p_plugin);
  
  return(&plugin);
}

WRAP_NAME * get_plugin(const char *p_arch, const char *p_plugin)
{
  static WRAP_NAME plugin;

  WRAP_NAME *p_dir = get_plugin_dir(p_arch);  
  
  snprintf(plugin.name,MAX_NAME,"%s/%s",p_dir->name,p_plugin);
  snprintf(plugin.name_wrapped,MAX_NAME,"%s/%s",p_dir->name_wrapped,p_plugin);
  
  return(&plugin);
}

char * get_viewer_32(void)
{
  static char viewer_32[] = { NPW_VIEWER_32 };
  return(viewer_32);  
}

char * get_viewer_64(void)
{
  static char viewer_64[] = { NPW_VIEWER_64 };
  return(viewer_64);
}

char * get_viewer_bits(int bits)
{
  if(bits == 32) {
    return(get_viewer_32());
  }
  else if(bits == 64) {
    return(get_viewer_64());
  } 
  else {
    assert(0);
    return(NULL);
  }
}

char * get_viewer(const char * p_arch)
{
  return(get_viewer_bits(get_bits(p_arch)));
}

char * get_wrapper_32(void)
{
  static char wrapper_32[] = { NPW_WRAPPER_32 };
  return(wrapper_32);  
}

char * get_wrapper_64(void)
{
  static char wrapper_64[] = { NPW_WRAPPER_64 };
  return(wrapper_64);
}

char * get_wrapper_bits(int bits)
{  
  if(bits == 32) {
    return(get_wrapper_32());
  }
  else if(bits == 64) {
    return(get_wrapper_64());
  } 
  else {
    assert(0);
    return(NULL);
  }
}

char * get_wrapper(const char * p_arch)
{  
  return(get_wrapper_bits(get_bits(p_arch)));
}
